@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimauthenticationstatusinfotest.h"
@@ -43,15 +30,65 @@ void DKIMAuthenticationStatusInfoTest::shouldParseKey()
     QFETCH(MessageViewer::DKIMAuthenticationStatusInfo, result);
     QFETCH(bool, relaxingParsing);
     QFETCH(bool, success);
-    MessageViewer::DKIMAuthenticationStatusInfo info;
-    const bool val = info.parseAuthenticationStatus(key, relaxingParsing);
-    QCOMPARE(val, success);
-    const bool compareResult = result == info;
-    if (!compareResult) {
-        qDebug() << "parse info: " << info;
-        qDebug() << "expected: " << result;
+    QBENCHMARK {
+        MessageViewer::DKIMAuthenticationStatusInfo info;
+        const bool val = info.parseAuthenticationStatus(key, relaxingParsing);
+        QCOMPARE(val, success);
+        const bool compareResult = result == info;
+        if (!compareResult) {
+            qDebug() << "parse info: " << info;
+            qDebug() << "expected: " << result;
+        }
+        QVERIFY(compareResult);
     }
-    QVERIFY(compareResult);
+    //    Before
+    //        PASS   : DKIMAuthenticationStatusInfoTest::initTestCase()
+    //        PASS   : DKIMAuthenticationStatusInfoTest::shouldHaveDefaultValue()
+    //        PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(empty)
+    //        RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"empty":
+    //             0.81 msecs per iteration (total: 52, iterations: 64)
+    //        PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(test1)
+    //        RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"test1":
+    //             18 msecs per iteration (total: 72, iterations: 4)
+    //        PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(none)
+    //        RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"none":
+    //             2.0 msecs per iteration (total: 65, iterations: 32)
+    //        PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(none2)
+    //        RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"none2":
+    //             2.0 msecs per iteration (total: 66, iterations: 32)
+    //        PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(reason)
+    //        RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"reason":
+    //             13 msecs per iteration (total: 52, iterations: 4)
+    //        PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(reason2)
+    //        RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"reason2":
+    //             12 msecs per iteration (total: 97, iterations: 8)
+    //        PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(gmails)
+    //        RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"gmails":
+    //             7.0 msecs per iteration (total: 56, iterations: 8)
+    //        PASS   : DKIMAuthenticationStatusInfoTest::cleanupTestCase()
+
+    //    AFTER
+    // RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"empty":
+    //     0.0089 msecs per iteration (total: 73, iterations: 8192)
+    // PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(test1)
+    // RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"test1":
+    //     0.23 msecs per iteration (total: 59, iterations: 256)
+    // PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(none)
+    // RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"none":
+    //     0.023 msecs per iteration (total: 96, iterations: 4096)
+    // PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(none2)
+    // RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"none2":
+    //     0.023 msecs per iteration (total: 96, iterations: 4096)
+    // PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(reason)
+    // RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"reason":
+    //     0.16 msecs per iteration (total: 83, iterations: 512)
+    // PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(reason2)
+    // RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"reason2":
+    //     0.14 msecs per iteration (total: 75, iterations: 512)
+    // PASS   : DKIMAuthenticationStatusInfoTest::shouldParseKey(gmails)
+    // RESULT : DKIMAuthenticationStatusInfoTest::shouldParseKey():"gmails":
+    //     0.085 msecs per iteration (total: 88, iterations: 1024)
+    // PASS   : DKIMAuthenticationStatusInfoTest::cleanupTestCase()
 }
 
 void DKIMAuthenticationStatusInfoTest::shouldParseKey_data()
@@ -123,30 +160,24 @@ void DKIMAuthenticationStatusInfoTest::shouldParseKey_data()
         lst.append(property3);
 
         info.setListAuthStatusInfo(lst);
-        QTest::addRow("test1") << QStringLiteral("in68.mail.ovh.net; dkim=pass (2048-bit key; unprotected) header.d=kde.org header.i=@kde.org header.b=\"GMG2ucPx\"; dkim=pass (2048-bit key; unprotected) header.d=kde.org header.i=@kde.org header.b=\"I3t3p7Up\"; dkim-atps=neutral")
-                               << info
-                               << false
-                               << true;
+        QTest::addRow("test1") << QStringLiteral(
+            "in68.mail.ovh.net; dkim=pass (2048-bit key; unprotected) header.d=kde.org header.i=@kde.org header.b=\"GMG2ucPx\"; dkim=pass (2048-bit key; "
+            "unprotected) header.d=kde.org header.i=@kde.org header.b=\"I3t3p7Up\"; dkim-atps=neutral")
+                               << info << false << true;
     }
     {
         MessageViewer::DKIMAuthenticationStatusInfo info;
         info.setAuthVersion(1);
         info.setAuthservId(QStringLiteral("example.org"));
 
-        QTest::addRow("none") << QStringLiteral("example.org 1; none;")
-                              << info
-                              << false
-                              << false;
+        QTest::addRow("none") << QStringLiteral("example.org 1; none;") << info << false << false;
     }
     {
         MessageViewer::DKIMAuthenticationStatusInfo info;
         info.setAuthVersion(1);
         info.setAuthservId(QStringLiteral("example.org"));
 
-        QTest::addRow("none2") << QStringLiteral("example.org 1; none")
-                               << info
-                               << false
-                               << false;
+        QTest::addRow("none2") << QStringLiteral("example.org 1; none") << info << false << false;
     }
     {
         MessageViewer::DKIMAuthenticationStatusInfo info;
@@ -185,13 +216,13 @@ void DKIMAuthenticationStatusInfoTest::shouldParseKey_data()
         }
         info.setListAuthStatusInfo(lst);
 
-        QTest::addRow("reason") << QStringLiteral("example.com; dkim=pass reason=\"good signature\" header.i=@mail-router.example.net; dkim=fail reason=\"bad signature\" header.i=@newyork.example.com;")
-                                << info
-                                << false
-                                << true;
+        QTest::addRow("reason") << QStringLiteral(
+            "example.com; dkim=pass reason=\"good signature\" header.i=@mail-router.example.net; dkim=fail reason=\"bad signature\" "
+            "header.i=@newyork.example.com;")
+                                << info << false << true;
     }
 
-    //It will failed. Fix it
+    // It will failed. Fix it
     {
         MessageViewer::DKIMAuthenticationStatusInfo info;
         info.setAuthVersion(1);
@@ -229,10 +260,10 @@ void DKIMAuthenticationStatusInfoTest::shouldParseKey_data()
         }
         info.setListAuthStatusInfo(lst);
 
-        QTest::addRow("reason2") << QStringLiteral("example.com; dkim=pass reason=\"good signature\" header.i=@mail-router.example.net; dkim=fail reason=\"bad signature\" header.i=@newyork.example.com")
-                                 << info
-                                 << true
-                                 << true;
+        QTest::addRow("reason2") << QStringLiteral(
+            "example.com; dkim=pass reason=\"good signature\" header.i=@mail-router.example.net; dkim=fail reason=\"bad signature\" "
+            "header.i=@newyork.example.com")
+                                 << info << true << true;
     }
     {
         MessageViewer::DKIMAuthenticationStatusInfo info;
@@ -254,9 +285,6 @@ void DKIMAuthenticationStatusInfoTest::shouldParseKey_data()
         }
         info.setListAuthStatusInfo(lst);
 
-        QTest::addRow("gmails") << QStringLiteral("letterbox.kde.org; dmarc=pass (p=none dis=none) header.from=gmail.com\r\n")
-                                << info
-                                << true
-                                << true;
+        QTest::addRow("gmails") << QStringLiteral("letterbox.kde.org; dmarc=pass (p=none dis=none) header.from=gmail.com\r\n") << info << true << true;
     }
 }
