@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ DKIMManageRulesComboBox::DKIMManageRulesComboBox(QWidget *parent)
     init();
 }
 
-DKIMManageRulesComboBox::~DKIMManageRulesComboBox()
-{
-}
+DKIMManageRulesComboBox::~DKIMManageRulesComboBox() = default;
 
 void DKIMManageRulesComboBox::init()
 {
