@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -40,7 +40,6 @@ public:
 
 private:
     Q_DISABLE_COPY(ViewerPluginManager)
-    ViewerPluginManagerPrivate *const d;
+    std::unique_ptr<ViewerPluginManagerPrivate> const d;
 };
 }
-
