@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATEPARSEREMAILADDRESSREQUESTERINTERFACEWIDGET_H
-#define TEMPLATEPARSEREMAILADDRESSREQUESTERINTERFACEWIDGET_H
+#pragma once
 
 #include "templateparser_private_export.h"
 #include <QWidget>
@@ -31,4 +30,3 @@ private:
     TemplateParser::TemplateParserEmailAddressRequesterBase *mTemplateParserEmailBase = nullptr;
 };
 }
-#endif // TEMPLATEPARSEREMAILADDRESSREQUESTERINTERFACEWIDGET_H
