@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ LocalDataBaseFileTest::LocalDataBaseFileTest(QObject *parent)
     QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/phishingurl"));
 }
 
-LocalDataBaseFileTest::~LocalDataBaseFileTest()
-{
-}
+LocalDataBaseFileTest::~LocalDataBaseFileTest() = default;
 
 void LocalDataBaseFileTest::shouldBeInvalidWithUnExistingFile()
 {
