@@ -37,7 +37,9 @@ void TestSelectionChangedEngine::slotSelectionChanged()
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     auto testWebEngine = new TestSelectionChangedEngine;
     testWebEngine->show();
     const int ret = app.exec();
